@@ -15,8 +15,9 @@ use Jenkins::API;
 use Term::ANSIColor qw/colored/;
 use File::ShareDir qw/dist_dir/;
 use Path::Tiny;
+use DateTime;
 
-our $VERSION = "0.007";
+our $VERSION = "0.008";
 
 has [qw/base_url api_key api_pass test/] => (
     is => 'rw',
@@ -339,17 +340,17 @@ sub _action {
 
 sub _ls_job {
     my ($self, $jenkins, $return) = @_;
-    my $max = 0;
+    my ($max, $space) = (0, 8);
 
     return sub {
         my $name = $_->{name};
-        my $extra = ' ';
+        my ($extra_pre, $extra_post) = ('') x 2;
 
         if ( ! $_->{color} ) {
             $_->{color} = '';
         }
         elsif ( $_->{color} =~ s/_anime// ) {
-            $extra = '*';
+            $extra_pre = '*';
         }
 
         if ( $self->opt->{verbose} ) {
@@ -358,17 +359,34 @@ sub _ls_job {
                     ['job', $_->{name}, qw/api json/],
                     {
                         extra_params => {
-                            depth => 0,
-                            tree => 'lastBuild[timestamp,displayName,builtOn]'
+                            depth => 1,
+                            tree => 'lastBuild[timestamp,displayName,builtOn,duration]'
                         }
                     }
                 );
-                $extra .= "\t" . localtime( ( $details->{lastBuild}{timestamp} || 0 ) / 1000 );
-                if ( $details->{lastBuild}{displayName} && $details->{lastBuild}{builtOn} ) {
-                    $extra .= "\t($details->{lastBuild}{displayName} / $details->{lastBuild}{builtOn})";
+                my $duration = $details->{lastBuild}{duration} / 1_000;
+                if ( $duration > 2 * 60 * 60 ) {
+                    $duration = int($duration / 60 / 60) . ' hrs';
+                }
+                elsif ( $duration >= 60 * 60 ) {
+                    $duration = '1 hr ' . (int( ($duration - 60 * 60) / 60 )) . ' min';
+                }
+                elsif ( $duration > 2 * 60 ) {
+                    $duration = int($duration / 60 ) . ' min';
+                }
+                elsif ( $duration >= 60 ) {
+                    $duration = '1 min ' . ($duration - 60) . ' sec';
                 }
                 else {
-                    $extra .= "\tNever run";
+                    $duration .= ' sec';
+                }
+
+                $extra_post .= DateTime->from_epoch( epoch => ( $details->{lastBuild}{timestamp} || 0 ) / 1000 );
+                if ( $details->{lastBuild}{displayName} && $details->{lastBuild}{builtOn} ) {
+                    $extra_post .= " ($duration / $details->{lastBuild}{displayName} / $details->{lastBuild}{builtOn})";
+                }
+                else {
+                    $extra_post .= "Never run";
                 }
                 1;
             } or do {
@@ -380,11 +398,15 @@ sub _ls_job {
         # map "jenkins" colours to real colours
         my $color = $self->colour_map->{$_->{color}} || [$_->{color}];
 
-        if ( length $name > $max ) {
-            $max = length $name;
+        if ( !$max ) {
+            $max = $space + length $name . " $extra_pre";
+        }
+        elsif ( length $name > $max ) {
+            $max = $space + length $name . " $extra_pre";
+            $space -= 2 if $space > 2;
         }
 
-        my $out = colored($color, sprintf "% -${max}s", $name) . " $extra\n";
+        my $out = colored($color, sprintf "% -${max}s", "$name $extra_pre") . " $extra_post\n";
 
         if ( $self->opt->{long} ) {
             $out = "$_->{color} $out";
@@ -407,7 +429,7 @@ App::JenkinsCli - Command line tool for interacting with Jenkins
 
 =head1 VERSION
 
-This documentation refers to App::JenkinsCli version 0.007
+This documentation refers to App::JenkinsCli version 0.008
 
 =head1 SYNOPSIS
 
